@@ -18,9 +18,9 @@ from novel_downloader.cli import ui
 from novel_downloader.config import ConfigAdapter, load_config
 from novel_downloader.core import get_downloader, get_exporter, get_fetcher, get_parser
 from novel_downloader.models import BookConfig, LoginField
+from novel_downloader.utils.book_url_resolver import resolve_book_url
 from novel_downloader.utils.cookies import parse_cookies
 from novel_downloader.utils.i18n import t
-from novel_downloader.utils.logger import setup_logging
 
 
 def register_download_subcommand(subparsers: _SubParsersAction) -> None:  # type: ignore
@@ -28,9 +28,7 @@ def register_download_subcommand(subparsers: _SubParsersAction) -> None:  # type
     parser = subparsers.add_parser("download", help=t("help_download"))
 
     parser.add_argument("book_ids", nargs="*", help=t("download_book_ids"))
-    parser.add_argument(
-        "--site", default="qidian", help=t("download_option_site", default="qidian")
-    )
+    parser.add_argument("--site", help=t("download_option_site"))
     parser.add_argument("--config", type=str, help=t("help_config"))
 
     parser.add_argument("--start", type=str, help=t("download_option_start"))
@@ -47,13 +45,36 @@ def register_download_subcommand(subparsers: _SubParsersAction) -> None:  # type
 
 def handle_download(args: Namespace) -> None:
     """Handle the `download` subcommand."""
-    site: str = args.site
     config_path: Path | None = Path(args.config) if args.config else None
-    book_ids: list[BookConfig] = _cli_args_to_book_configs(
-        args.book_ids, args.start, args.end
-    )
     no_export: bool = getattr(args, "no_export", False)
 
+    site: str | None = args.site
+    if site:  # SITE MODE
+        book_ids: list[BookConfig] = _cli_args_to_book_configs(
+            args.book_ids, args.start, args.end
+        )
+    else:  # URL MODE
+        ui.info(t("download_url_mode"))
+        if len(args.book_ids) != 1:
+            ui.error(t("download_url_expected", n=len(args.book_ids)))
+            return
+
+        raw_url = args.book_ids[0]
+        resolved = resolve_book_url(raw_url)
+        if not resolved:
+            ui.error(t("download_url_parse_fail", url=raw_url))
+            return
+
+        site = resolved["site_key"]
+        first: BookConfig = {"book_id": resolved["book"]["book_id"]}
+        if args.start:
+            first["start_id"] = args.start
+        if args.end:
+            first["end_id"] = args.end
+        book_ids = [first]
+
+        ui.info(t("download_resolved", site=site, book_id=first["book_id"]))
+
     ui.info(t("download_site_info", site=site))
 
     try:
@@ -64,7 +85,7 @@ def handle_download(args: Namespace) -> None:
 
     adapter = ConfigAdapter(config=config_data, site=site)
 
-    if not book_ids:
+    if not book_ids and args.site:
         try:
             book_ids = adapter.get_book_ids()
         except Exception as e:
@@ -155,7 +176,7 @@ async def _download(
     exporter_cfg = adapter.get_exporter_config()
     login_cfg = adapter.get_login_config()
     log_level = adapter.get_log_level()
-    setup_logging(log_level=log_level)
+    ui.setup_logging(console_level=log_level)
 
     parser = get_parser(site, parser_cfg)
     exporter = None
@@ -178,7 +199,14 @@ async def _download(
 
         for book in valid_books:
             ui.info(t("download_downloading", book_id=book["book_id"], site=site))
-            await downloader.download(book, progress_hook=_print_progress)
+
+            hook, close = ui.create_progress_hook(
+                prefix=t("download_progress_prefix"), unit="chapters"
+            )
+            try:
+                await downloader.download(book, progress_hook=hook)
+            finally:
+                close()
 
             if not no_export and exporter is not None:
                 await asyncio.to_thread(exporter.export, book["book_id"])
@@ -186,6 +214,9 @@ async def _download(
         if downloader_cfg.login_required and fetcher.is_logged_in:
             await fetcher.save_state()
 
+    if exporter is not None:
+        exporter.close()
+
 
 async def _prompt_login_fields(
     fields: list[LoginField],
@@ -214,8 +245,8 @@ async def _prompt_login_fields(
             ui.info(t("login_use_config"))
             continue
 
-        value: str | dict[str, str]
-        while True:
+        value: str | dict[str, str] = ""
+        for _ in range(5):
             if field.type == "password":
                 value = ui.prompt_password(t("login_enter_password"))
             elif field.type == "cookie":
@@ -235,10 +266,3 @@ async def _prompt_login_fields(
         result[field.name] = value
 
     return result
-
-
-async def _print_progress(done: int, total: int) -> None:
-    """Progress hook passed into the downloader."""
-    ui.print_progress(
-        done, total, prefix=t("download_progress_prefix"), unit="chapters"
-    )
