@@ -15,7 +15,6 @@ from novel_downloader.cli import ui
 from novel_downloader.config import ConfigAdapter, load_config
 from novel_downloader.core import get_exporter
 from novel_downloader.utils.i18n import t
-from novel_downloader.utils.logger import setup_logging
 
 
 def register_export_subcommand(subparsers: _SubParsersAction) -> None:  # type: ignore
@@ -30,7 +29,7 @@ def register_export_subcommand(subparsers: _SubParsersAction) -> None:  # type:
         help=t("export_format_help"),
     )
     parser.add_argument(
-        "--site", default="qidian", help=t("download_option_site", default="qidian")
+        "--site", default="qidian", help=t("export_option_site", default="qidian")
     )
     parser.add_argument("--config", type=str, help=t("help_config"))
 
@@ -55,22 +54,22 @@ def handle_export(args: Namespace) -> None:
     adapter = ConfigAdapter(config=config_data, site=site)
     exporter_cfg = adapter.get_exporter_config()
     log_level = adapter.get_log_level()
-    exporter = get_exporter(site, exporter_cfg)
-    setup_logging(log_level=log_level)
+    ui.setup_logging(console_level=log_level)
 
-    for book_id in book_ids:
-        ui.info(t("export_processing", book_id=book_id, format=export_format))
+    with get_exporter(site, exporter_cfg) as exporter:
+        for book_id in book_ids:
+            ui.info(t("export_processing", book_id=book_id, format=export_format))
 
-        if export_format in {"txt", "all"}:
-            try:
-                exporter.export_as_txt(book_id)
-                ui.success(t("export_success_txt", book_id=book_id))
-            except Exception as e:
-                ui.error(t("export_failed_txt", book_id=book_id, err=str(e)))
+            if export_format in {"txt", "all"}:
+                try:
+                    exporter.export_as_txt(book_id)
+                    ui.success(t("export_success_txt", book_id=book_id))
+                except Exception as e:
+                    ui.error(t("export_failed_txt", book_id=book_id, err=str(e)))
 
-        if export_format in {"epub", "all"}:
-            try:
-                exporter.export_as_epub(book_id)
-                ui.success(t("export_success_epub", book_id=book_id))
-            except Exception as e:
-                ui.error(t("export_failed_epub", book_id=book_id, err=str(e)))
+            if export_format in {"epub", "all"}:
+                try:
+                    exporter.export_as_epub(book_id)
+                    ui.success(t("export_success_epub", book_id=book_id))
+                except Exception as e:
+                    ui.error(t("export_failed_epub", book_id=book_id, err=str(e)))
