@@ -7,12 +7,10 @@ This package serves as the core layer of the novel_downloader system.
 
 It provides factory methods for constructing key components required for
 downloading and processing online novel content, including:
-
-- Downloader: Handles the full download lifecycle of a book or a batch of books.
-- Parser: Extracts structured data from HTML or SSR content.
-- Fetcher: Sends HTTP requests and manages sessions, including login if required.
-- Exporter: Responsible for exporting downloaded data into various output formats.
-- search: Provides unified search functionality across supported novel sites.
+  * Downloader: Handles the full download lifecycle of a book or a batch of books.
+  * Parser: Extracts structured data from HTML or SSR content.
+  * Fetcher: Sends HTTP requests and manages sessions, including login if required.
+  * Exporter: Responsible for exporting downloaded data into various output formats.
 """
 
 __all__ = [
@@ -20,7 +18,6 @@ __all__ = [
     "get_exporter",
     "get_fetcher",
     "get_parser",
-    "search",
     "DownloaderProtocol",
     "ExporterProtocol",
     "FetcherProtocol",
@@ -37,4 +34,3 @@ from .interfaces import (
     ParserProtocol,
 )
 from .parsers import get_parser
-from .searchers import search
