@@ -10,25 +10,21 @@ import abc
 import asyncio
 import json
 import logging
-from collections.abc import AsyncIterator, Awaitable, Callable, Sequence
+import re
+from collections.abc import Awaitable, Callable, Sequence
 from pathlib import Path
-from typing import Any, cast
+from typing import Any, ClassVar
 
-from novel_downloader.core.interfaces import (
-    DownloaderProtocol,
-    FetcherProtocol,
-    ParserProtocol,
-)
+from novel_downloader.core.interfaces import FetcherProtocol, ParserProtocol
 from novel_downloader.models import (
     BookConfig,
     BookInfoDict,
     DownloaderConfig,
     VolumeInfoDict,
 )
-from novel_downloader.utils import time_diff
 
 
-class BaseDownloader(DownloaderProtocol, abc.ABC):
+class BaseDownloader(abc.ABC):
     """
     Abstract base class for novel downloaders.
 
@@ -39,11 +35,16 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
     a single book, using the provided fetcher and parser components.
     """
 
-    DEFAULT_SOURCE_ID = 0
-    PRIORITIES_MAP = {
+    DEFAULT_SOURCE_ID: ClassVar[int] = 0
+    PRIORITIES_MAP: ClassVar[dict[int, int]] = {
         DEFAULT_SOURCE_ID: 0,
     }
 
+    _IMG_SRC_RE = re.compile(
+        r'<img[^>]*\bsrc\s*=\s*["\'](https?://[^"\']+)["\'][^>]*>',
+        re.IGNORECASE,
+    )
+
     def __init__(
         self,
         fetcher: FetcherProtocol,
@@ -61,15 +62,21 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
         """
         self._fetcher = fetcher
         self._parser = parser
-        self._config = config
         self._site = site
 
-        self._raw_data_dir = Path(config.raw_data_dir) / site
-        self._raw_data_dir.mkdir(parents=True, exist_ok=True)
-        self._debug_dir = Path.cwd() / "debug" / site
-        self._debug_dir.mkdir(parents=True, exist_ok=True)
+        self._save_html = config.save_html
+        self._skip_existing = config.skip_existing
+        self._login_required = config.login_required
+        self._request_interval = config.request_interval
+        self._retry_times = config.retry_times
+        self._backoff_factor = config.backoff_factor
+        self._workers = config.workers
+        self._storage_batch_size = max(1, config.storage_batch_size)
 
-        self.logger = logging.getLogger(f"{self.__class__.__name__}")
+        self._raw_data_dir = Path(config.raw_data_dir) / site
+        self._debug_dir = Path.cwd() / "debug" / site
+
+        self.logger = logging.getLogger(f"{__name__}.{self.__class__.__name__}")
 
     async def download_many(
         self,
@@ -87,10 +94,10 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
                                 args: completed_count, total_count.
         :param cancel_event: Optional asyncio.Event to allow cancellation.
         """
-        if not await self._ensure_ready():
+        if not self._check_login():
             book_ids = [b["book_id"] for b in books]
             self.logger.warning(
-                "[%s] login failed, skipping download of books: %s",
+                "%s login failed, skipping download of books: %s",
                 self._site,
                 ", ".join(book_ids) or "<none>",
             )
@@ -100,7 +107,7 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
             # stop early if cancellation requested
             if cancel_event and cancel_event.is_set():
                 self.logger.info(
-                    "[%s] download cancelled before book: %s",
+                    "%s download cancelled before book: %s",
                     self._site,
                     book["book_id"],
                 )
@@ -116,8 +123,6 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
             except Exception as e:
                 self._handle_download_exception(book, e)
 
-        await self._finalize()
-
     async def download(
         self,
         book: BookConfig,
@@ -134,19 +139,20 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
                                 args: completed_count, total_count.
         :param cancel_event: Optional asyncio.Event to allow cancellation.
         """
-        if not await self._ensure_ready():
+        if not self._check_login():
             self.logger.warning(
-                "[%s] login failed, skipping download of book: %s (%s-%s)",
+                "%s login failed, skipping download of book: %s (%s-%s)",
                 self._site,
                 book["book_id"],
                 book.get("start_id", "-"),
                 book.get("end_id", "-"),
             )
+            return
 
         # if already cancelled before starting
         if cancel_event and cancel_event.is_set():
             self.logger.info(
-                "[%s] download cancelled before start of book: %s",
+                "%s download cancelled before start of book: %s",
                 self._site,
                 book["book_id"],
             )
@@ -162,30 +168,6 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
         except Exception as e:
             self._handle_download_exception(book, e)
 
-        await self._finalize()
-
-    async def load_book_info(
-        self,
-        book_id: str,
-        html_dir: Path,
-    ) -> BookInfoDict | None:
-        book_info = self._load_book_info(
-            book_id=book_id,
-            max_age_days=1,
-        )
-        if book_info:
-            return book_info
-
-        info_html = await self.fetcher.get_book_info(book_id)
-        self._save_html_pages(html_dir, "info", info_html)
-        book_info = self.parser.parse_book_info(info_html)
-
-        if book_info:
-            self._save_book_info(book_id, book_info)
-            return book_info
-
-        return self._load_book_info(book_id)
-
     @abc.abstractmethod
     async def _download_one(
         self,
@@ -200,61 +182,26 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
         """
         ...
 
-    async def _prepare(self) -> None:
+    async def _load_book_info(self, book_id: str) -> BookInfoDict | None:
         """
-        Optional hook called before downloading.
-
-        Subclasses can override this method to perform pre-download setup.
-        """
-        return
-
-    async def _finalize(self) -> None:
-        """
-        Optional hook called after downloading is complete.
-
-        Subclasses can override this method to perform post-download tasks,
-        such as saving state or releasing resources.
-        """
-        return
-
-    def _load_book_info(
-        self,
-        book_id: str,
-        *,
-        max_age_days: int | None = None,
-    ) -> BookInfoDict | None:
-        """
-        Attempt to read and parse the book_info.json for a given book_id.
+        Attempt to fetch and parse the book_info for a given book_id.
 
         :param book_id: identifier of the book
-        :param max_age_days: if set, only return if 'update_time' is less
-        :return: dict of book info if is valid JSON, else empty
         """
-        info_path = self._raw_data_dir / book_id / "book_info.json"
-        if not info_path.is_file():
-            return None
-
-        try:
-            raw: dict[str, Any] = json.loads(info_path.read_text(encoding="utf-8"))
-        except json.JSONDecodeError:
-            return None
-
-        if max_age_days is not None:
-            days, *_ = time_diff(
-                raw.get("update_time", ""),
-                "UTC+8",
-            )
-            if days > max_age_days:
+        info_html = await self.fetcher.get_book_info(book_id)
+        self._save_html_pages(book_id, "info", info_html)
+        book_info = self.parser.parse_book_info(info_html)
+        if book_info:
+            self._save_book_info(book_id, book_info)
+        else:
+            info_path = self._raw_data_dir / book_id / "book_info.json"
+            try:
+                book_info = json.loads(info_path.read_text(encoding="utf-8"))
+            except json.JSONDecodeError:
                 return None
+        return book_info
 
-        # return data
-        return cast(BookInfoDict, raw)
-
-    def _save_book_info(
-        self,
-        book_id: str,
-        book_info: BookInfoDict,
-    ) -> None:
+    def _save_book_info(self, book_id: str, book_info: BookInfoDict) -> None:
         """
         Serialize and save the book_info dict as json.
 
@@ -270,38 +217,45 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
 
     def _save_html_pages(
         self,
-        html_dir: Path,
+        book_id: str,
         filename: str,
         html_list: Sequence[str],
+        *,
+        folder: str = "html",
     ) -> None:
         """
         If save_html is enabled, write each HTML snippet to a file.
 
         Filenames will be {chap_id}_{index}.html in html_dir.
 
-        :param html_dir: directory in which to write HTML files
+        :param book_id: The book identifier
         :param filename: used as filename prefix
         :param html_list: list of HTML strings to save
         """
-        if not self.save_html:
+        if not self._save_html:
             return
-
+        html_dir = self._debug_dir / book_id / folder
         html_dir.mkdir(parents=True, exist_ok=True)
         for i, html in enumerate(html_list):
-            file_path = html_dir / f"{filename}_{i}.html"
-            file_path.write_text(html, encoding="utf-8")
+            (html_dir / f"{filename}_{i}.html").write_text(html, encoding="utf-8")
+
+    @classmethod
+    def _extract_img_urls(cls, content: str) -> list[str]:
+        """
+        Extract all <img> tag src URLs from the given HTML string.
+        """
+        return cls._IMG_SRC_RE.findall(content)
 
     @staticmethod
-    async def _chapter_ids(
-        volumes: list[VolumeInfoDict],
+    def _planned_chapter_ids(
+        vols: list[VolumeInfoDict],
         start_id: str | None,
         end_id: str | None,
-    ) -> AsyncIterator[str]:
-        """
-        Yield each chapterId in order, respecting start/end bounds.
-        """
+        ignore: set[str],
+    ) -> list[str]:
         seen_start = start_id is None
-        for vol in volumes:
+        out: list[str] = []
+        for vol in vols:
             for chap in vol["chapters"]:
                 cid = chap.get("chapterId")
                 if not cid:
@@ -311,9 +265,11 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
                         seen_start = True
                     else:
                         continue
-                yield cid
+                if cid not in ignore:
+                    out.append(cid)
                 if end_id is not None and cid == end_id:
-                    return
+                    return out
+        return out
 
     @property
     def fetcher(self) -> FetcherProtocol:
@@ -323,38 +279,6 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
     def parser(self) -> ParserProtocol:
         return self._parser
 
-    @property
-    def save_html(self) -> bool:
-        return self._config.save_html
-
-    @property
-    def skip_existing(self) -> bool:
-        return self._config.skip_existing
-
-    @property
-    def login_required(self) -> bool:
-        return self._config.login_required
-
-    @property
-    def request_interval(self) -> float:
-        return self._config.request_interval
-
-    @property
-    def retry_times(self) -> int:
-        return self._config.retry_times
-
-    @property
-    def backoff_factor(self) -> float:
-        return self._config.backoff_factor
-
-    @property
-    def workers(self) -> int:
-        return self._config.workers
-
-    @property
-    def storage_batch_size(self) -> int:
-        return max(1, self._config.storage_batch_size)
-
     def _handle_download_exception(self, book: BookConfig, error: Exception) -> None:
         """
         Handle download errors in a consistent way.
@@ -365,7 +289,7 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
         :param error: The exception raised during download.
         """
         self.logger.warning(
-            "[%s] Failed to download (book_id=%s, start=%s, end=%s): %s",
+            "%s Failed to download (book_id=%s, start=%s, end=%s): %s",
             self.__class__.__name__,
             book.get("book_id", "<unknown>"),
             book.get("start_id", "-"),
@@ -373,10 +297,8 @@ class BaseDownloader(DownloaderProtocol, abc.ABC):
             error,
         )
 
-    async def _ensure_ready(self) -> bool:
+    def _check_login(self) -> bool:
         """
-        Run pre-download preparation and check login if needed.
+        Check login if needed.
         """
-        await self._prepare()
-
-        return self.fetcher.is_logged_in if self.login_required else True
+        return self.fetcher.is_logged_in if self._login_required else True
