@@ -9,6 +9,7 @@ Registry and factory helpers for creating site-specific or common downloaders
 __all__ = ["register_downloader", "get_downloader"]
 
 from collections.abc import Callable, Sequence
+from importlib import import_module
 from typing import TypeVar
 
 from novel_downloader.core.downloaders.common import CommonDownloader
@@ -20,11 +21,12 @@ from novel_downloader.core.interfaces import (
 from novel_downloader.models import DownloaderConfig
 
 DownloaderBuilder = Callable[
-    [FetcherProtocol, ParserProtocol, DownloaderConfig],
+    [FetcherProtocol, ParserProtocol, DownloaderConfig, str],
     DownloaderProtocol,
 ]
 D = TypeVar("D", bound=DownloaderProtocol)
 _DOWNLOADER_MAP: dict[str, DownloaderBuilder] = {}
+_DOWNLOADERS_PKG = "novel_downloader.core.downloaders"
 
 
 def register_downloader(
@@ -45,6 +47,33 @@ def register_downloader(
     return decorator
 
 
+def _normalize_key(site_key: str) -> str:
+    """
+    Normalize a site key to the expected module basename:
+      * lowercase
+      * if first char is a digit, prefix with 'n'
+    """
+    key = site_key.strip().lower()
+    if not key:
+        raise ValueError("Site key cannot be empty")
+    if key[0].isdigit():
+        return f"n{key}"
+    return key
+
+
+def _load_downloader(site_key: str) -> None:
+    """
+    Attempt to import the site-specific downloader module.
+    """
+    modname = f"{_DOWNLOADERS_PKG}.{site_key}"
+    try:
+        import_module(modname)
+    except ModuleNotFoundError as e:
+        if e.name == modname:
+            return
+        raise
+
+
 def get_downloader(
     fetcher: FetcherProtocol,
     parser: ParserProtocol,
@@ -61,9 +90,14 @@ def get_downloader(
 
     :return: An instance of a downloader class
     """
-    site_key = site.lower()
-    try:
-        downloader_cls = _DOWNLOADER_MAP[site_key]
-    except KeyError:
+    site_key = _normalize_key(site)
+
+    downloader_cls = _DOWNLOADER_MAP.get(site_key)
+    if downloader_cls is None:
+        _load_downloader(site_key)
+        downloader_cls = _DOWNLOADER_MAP.get(site_key)
+
+    if downloader_cls is None:
         return CommonDownloader(fetcher, parser, config, site_key)
-    return downloader_cls(fetcher, parser, config)
+
+    return downloader_cls(fetcher, parser, config, site_key)
