@@ -7,16 +7,16 @@ Abstract base class providing common structure and utilities for book exporters
 """
 
 import abc
+import contextlib
 import json
 import logging
 import types
 from datetime import datetime
 from pathlib import Path
-from typing import Any, Self, cast
+from typing import Any, ClassVar, Self, cast
 
-from novel_downloader.core.interfaces import ExporterProtocol
 from novel_downloader.models import BookInfoDict, ChapterDict, ExporterConfig
-from novel_downloader.utils import ChapterStorage
+from novel_downloader.utils import ChapterStorage, get_cleaner
 
 
 class SafeDict(dict[str, Any]):
@@ -24,15 +24,15 @@ class SafeDict(dict[str, Any]):
         return f"{{{key}}}"
 
 
-class BaseExporter(ExporterProtocol, abc.ABC):
+class BaseExporter(abc.ABC):
     """
     BaseExporter defines the interface and common structure for
     saving assembled book content into various formats
     such as TXT, EPUB, Markdown, or PDF.
     """
 
-    DEFAULT_SOURCE_ID = 0
-    PRIORITIES_MAP = {
+    DEFAULT_SOURCE_ID: ClassVar[int] = 0
+    PRIORITIES_MAP: ClassVar[dict[int, int]] = {
         DEFAULT_SOURCE_ID: 0,
     }
 
@@ -47,15 +47,29 @@ class BaseExporter(ExporterProtocol, abc.ABC):
         :param config: Exporter configuration settings.
         :param site: Identifier for the target website or source.
         """
-        self._config = config
         self._site = site
         self._storage_cache: dict[str, ChapterStorage] = {}
 
+        self._make_txt = config.make_txt
+        self._make_epub = config.make_epub
+        self._make_md = config.make_md
+        self._make_pdf = config.make_pdf
+
+        self._include_cover = config.include_cover
+        self._include_picture = config.include_picture
+        self._split_mode = config.split_mode
+        self._filename_template = config.filename_template
+        self._append_timestamp = config.append_timestamp
+
         self._raw_data_dir = Path(config.raw_data_dir) / site
         self._output_dir = Path(config.output_dir)
-        self._output_dir.mkdir(parents=True, exist_ok=True)
 
-        self.logger = logging.getLogger(f"{self.__class__.__name__}")
+        self._cleaner = get_cleaner(
+            enabled=config.clean_text,
+            config=config.cleaner_cfg,
+        )
+
+        self.logger = logging.getLogger(f"{__name__}.{self.__class__.__name__}")
 
     def export(self, book_id: str) -> dict[str, Path]:
         """
@@ -63,22 +77,20 @@ class BaseExporter(ExporterProtocol, abc.ABC):
 
         :param book_id: The book identifier (used for filename, lookup, etc.)
         """
-        TAG = "[Exporter]"
         results: dict[str, Path] = {}
 
         actions = [
-            ("make_txt", "txt", self.export_as_txt),
-            ("make_epub", "epub", self.export_as_epub),
-            ("make_md", "md", self.export_as_md),
-            ("make_pdf", "pdf", self.export_as_pdf),
+            (self._make_txt, "txt", self.export_as_txt),
+            (self._make_epub, "epub", self.export_as_epub),
+            (self._make_md, "md", self.export_as_md),
+            (self._make_pdf, "pdf", self.export_as_pdf),
         ]
 
-        for flag_name, fmt_key, export_method in actions:
-            if getattr(self._config, flag_name, False):
+        for enabled, fmt_key, export_method in actions:
+            if enabled:
                 try:
                     self.logger.info(
-                        "%s Attempting to export book_id '%s' as %s...",
-                        TAG,
+                        "Attempting to export book_id '%s' as %s...",
                         book_id,
                         fmt_key,
                     )
@@ -86,23 +98,19 @@ class BaseExporter(ExporterProtocol, abc.ABC):
 
                     if isinstance(path, Path):
                         results[fmt_key] = path
-                        self.logger.info("%s Successfully saved as %s.", TAG, fmt_key)
+                        self.logger.info("Successfully saved as %s.", fmt_key)
 
                 except NotImplementedError as e:
                     self.logger.warning(
-                        "%s Export method for %s not implemented: %s",
-                        TAG,
+                        "Export method for %s not implemented: %s",
                         fmt_key,
-                        str(e),
-                    )
-                except Exception as e:
-                    self.logger.error(
-                        "%s Error while saving as %s: %s", TAG, fmt_key, str(e)
+                        e,
                     )
+                except Exception:
+                    self.logger.exception("Error while saving as %s", fmt_key)
 
         return results
 
-    @abc.abstractmethod
     def export_as_txt(self, book_id: str) -> Path | None:
         """
         Persist the assembled book as a .txt file.
@@ -111,7 +119,7 @@ class BaseExporter(ExporterProtocol, abc.ABC):
 
         :param book_id: The book identifier (used for filename, lookup, etc.)
         """
-        ...
+        raise NotImplementedError("TXT export not supported by this Exporter.")
 
     def export_as_epub(self, book_id: str) -> Path | None:
         """
@@ -157,39 +165,12 @@ class BaseExporter(ExporterProtocol, abc.ABC):
         :param extra_fields: Any additional fields used in the filename template.
         :return: Formatted filename with extension.
         """
-        # Merge all fields with defaults
         context = SafeDict(title=title, author=author or "", **extra_fields)
-
-        name = self.filename_template.format_map(context)
-
-        if self._config.append_timestamp:
+        name = self._filename_template.format_map(context)
+        if self._append_timestamp:
             name += f"_{datetime.now().strftime('%Y%m%d_%H%M%S')}"
-
         return f"{name}.{ext}"
 
-    @property
-    def site(self) -> str:
-        """
-        Get the site identifier.
-
-        :return: The site string.
-        """
-        return self._site
-
-    @property
-    def output_dir(self) -> Path:
-        """
-        Access the output directory for saving files.
-        """
-        return self._output_dir
-
-    @property
-    def filename_template(self) -> str:
-        """
-        Access the filename template.
-        """
-        return self._config.filename_template
-
     def _get_chapter(
         self,
         book_id: str,
@@ -245,18 +226,10 @@ class BaseExporter(ExporterProtocol, abc.ABC):
                 self.logger.warning("Failed to close storage %s: %s", storage, e)
         self._storage_cache.clear()
 
-    def _on_close(self) -> None:
-        """
-        Hook method called at the beginning of close().
-        Override in subclass if needed.
-        """
-        pass
-
     def close(self) -> None:
         """
         Shutdown and clean up the exporter.
         """
-        self._on_close()
         self._close_chapter_storages()
 
     def __enter__(self) -> Self:
@@ -271,4 +244,5 @@ class BaseExporter(ExporterProtocol, abc.ABC):
         self.close()
 
     def __del__(self) -> None:
-        self.close()
+        with contextlib.suppress(Exception):
+            self.close()
