@@ -6,18 +6,13 @@ novel_downloader.core.interfaces.exporter
 Protocol defining the interface for exporting books to text, EPUB, and other formats.
 """
 
+import types
 from pathlib import Path
-from typing import Protocol, runtime_checkable
+from typing import Protocol, Self, runtime_checkable
 
 
 @runtime_checkable
 class ExporterProtocol(Protocol):
-    """
-    A exporter must implement a method to persist a completed book as plain text.
-
-    It may also optionally implement an EPUB (or other format) exporter.
-    """
-
     def export(self, book_id: str) -> dict[str, Path]:
         """
         Export the book in the formats specified in config.
@@ -58,3 +53,20 @@ class ExporterProtocol(Protocol):
         :param book_id: The book identifier.
         """
         ...
+
+    def close(self) -> None:
+        """
+        Shutdown and clean up the exporter.
+        """
+        ...
+
+    def __enter__(self) -> Self:
+        ...
+
+    def __exit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_val: BaseException | None,
+        tb: types.TracebackType | None,
+    ) -> None:
+        ...
