@@ -7,7 +7,8 @@ Protocol defining the interface for asynchronous fetching, login, and session ma
 """
 
 import types
-from typing import Any, Protocol, Self, runtime_checkable
+from pathlib import Path
+from typing import Any, Literal, Protocol, Self, runtime_checkable
 
 from novel_downloader.models import LoginField
 
@@ -16,11 +17,29 @@ from novel_downloader.models import LoginField
 class FetcherProtocol(Protocol):
     """
     An async requester must be able to fetch raw HTML/data for:
-      - a book's info page,
-      - a specific chapter page,
+      * a book's info page,
+      * a specific chapter page,
     and manage login/shutdown asynchronously.
     """
 
+    async def init(
+        self,
+        **kwargs: Any,
+    ) -> None:
+        """
+        Perform async initialization, such as creating a session.
+
+        This should be called before using any other method
+        if initialization is required.
+        """
+        ...
+
+    async def close(self) -> None:
+        """
+        Shutdown and clean up any resources.
+        """
+        ...
+
     async def login(
         self,
         username: str = "",
@@ -64,50 +83,6 @@ class FetcherProtocol(Protocol):
         """
         ...
 
-    async def get_bookcase(
-        self,
-        **kwargs: Any,
-    ) -> list[str]:
-        """
-        Optional: Retrieve the HTML content of the authenticated
-        user's bookcase page asynchronously.
-
-        :return: The HTML markup of the bookcase page.
-        """
-        ...
-
-    async def fetch(
-        self,
-        url: str,
-        **kwargs: Any,
-    ) -> str:
-        """
-        Perform a generic HTTP request and return the response body as text.
-
-        :param url: The URL to request.
-        :return: The response content as a string (HTML or JSON or plain text).
-        """
-        ...
-
-    async def init(
-        self,
-        **kwargs: Any,
-    ) -> None:
-        """
-        Perform async initialization, such as
-        launching a browser or creating a session.
-
-        This should be called before using any other method
-        if initialization is required.
-        """
-        ...
-
-    async def close(self) -> None:
-        """
-        Shutdown and clean up any resources.
-        """
-        ...
-
     async def load_state(self) -> bool:
         """
         Restore session state from a persistent storage,
@@ -126,6 +101,24 @@ class FetcherProtocol(Protocol):
         """
         ...
 
+    async def download_images(
+        self,
+        img_dir: Path,
+        urls: list[str],
+        batch_size: int = 10,
+        *,
+        on_exist: Literal["overwrite", "skip", "rename"] = "skip",
+    ) -> None:
+        """
+        Download images to `img_dir` in batches.
+
+        :param img_dir: Destination folder.
+        :param urls: List of image URLs (http/https).
+        :param batch_size: Concurrency per batch.
+        :param on_exist: What to do when file exists.
+        """
+        ...
+
     @property
     def is_logged_in(self) -> bool:
         """
@@ -137,6 +130,9 @@ class FetcherProtocol(Protocol):
     def login_fields(self) -> list[LoginField]:
         ...
 
+    async def __aenter__(self) -> Self:
+        ...
+
     async def __aexit__(
         self,
         exc_type: type[BaseException] | None,
@@ -144,6 +140,3 @@ class FetcherProtocol(Protocol):
         tb: types.TracebackType | None,
     ) -> None:
         ...
-
-    async def __aenter__(self) -> Self:
-        ...
