@@ -12,41 +12,36 @@ from collections.abc import Iterable
 from pathlib import Path
 from typing import Any
 
-from novel_downloader.core.interfaces import ParserProtocol
 from novel_downloader.models import BookInfoDict, ChapterDict, ParserConfig
 
 
-class BaseParser(ParserProtocol, abc.ABC):
+class BaseParser(abc.ABC):
     """
     BaseParser defines the interface for extracting book metadata and chapter content
     from raw HTML.
 
-    This base class manages internal book state (e.g. current book ID) and supports
-    configuration-driven behavior such as content cleaning or formatting.
-
     Subclasses must implement actual parsing logic for specific sites.
     """
 
+    site_name: str
     ADS: set[str] = set()
 
     _SPACE_RE = re.compile(r"\s+")
 
-    def __init__(
-        self,
-        config: ParserConfig,
-    ):
+    def __init__(self, config: ParserConfig):
         """
         Initialize the parser with a configuration object.
 
         :param config: ParserConfig object controlling parsing behavior.
         """
-        self._config = config
         self._book_id: str | None = None
 
+        self._fontocr_cfg = config.fontocr_cfg
+        self._save_font_debug = config.save_font_debug
         self._decode_font: bool = config.decode_font
+        self._batch_size = config.batch_size
         self._use_truncation = config.use_truncation
         self._base_cache_dir = Path(config.cache_dir)
-        self._cache_dir = self._base_cache_dir
 
         self._ad_pattern = self._compile_ads_pattern()
 
@@ -80,34 +75,6 @@ class BaseParser(ParserProtocol, abc.ABC):
         """
         ...
 
-    @property
-    def book_id(self) -> str | None:
-        """
-        Current book ID in context.
-
-        :return: The current book identifier.
-        """
-        return self._book_id
-
-    @book_id.setter
-    def book_id(self, value: str) -> None:
-        """
-        Set current book ID and update debug paths if needed.
-
-        :param value: Book identifier.
-        """
-        self._book_id = value
-        self._cache_dir = self._base_cache_dir / value
-        self._on_book_id_set()
-
-    def _on_book_id_set(self) -> None:
-        """
-        Hook called when a new book ID is set.
-        Subclasses can override this to initialize
-        book-related folders or states.
-        """
-        pass
-
     def _compile_ads_pattern(self) -> re.Pattern[str] | None:
         """
         Compile a regex pattern from the ADS list, or return None if no ADS.
@@ -151,7 +118,14 @@ class BaseParser(ParserProtocol, abc.ABC):
     def _first_str(xs: list[str], replaces: list[tuple[str, str]] | None = None) -> str:
         replaces = replaces or []
         value: str = xs[0].strip() if xs else ""
-        for replace in replaces:
-            old, new = replace
+        for old, new in replaces:
+            value = value.replace(old, new)
+        return value
+
+    @staticmethod
+    def _join_strs(xs: list[str], replaces: list[tuple[str, str]] | None = None) -> str:
+        replaces = replaces or []
+        value = "\n".join(s.strip() for s in xs if s and s.strip())
+        for old, new in replaces:
             value = value.replace(old, new)
         return value
