@@ -27,6 +27,8 @@ class EsjzoneParser(BaseParser):
     Parser for esjzone book pages.
     """
 
+    site_name: str = "esjzone"
+
     # Chapter XPaths
     _CHAPTER_TEXT_XPATH = 'string(//div[contains(@class, "forum-content")])'
     _CHAPTER_CONTENT_NODES_XPATH = '//div[contains(@class, "forum-content")]/*'
@@ -128,9 +130,9 @@ class EsjzoneParser(BaseParser):
                 or tag == "summary"
             ):
                 # Handle possible volume title markers:
-                # - <h2>: standard volume header
-                # - <p class="non">: alternative volume header style
-                # - <summary>: fallback for stray <summary> tags outside <details>
+                # * <h2>: standard volume header
+                # * <p class="non">: alternative volume header style
+                # * <summary>: fallback for stray <summary> tags outside <details>
                 _start_volume(node.xpath("string()"))
 
             elif tag == "a":
@@ -210,7 +212,7 @@ class EsjzoneParser(BaseParser):
             "id": chapter_id,
             "title": title,
             "content": content,
-            "extra": {"site": "esjzone", "updated_at": updated_at},
+            "extra": {"site": self.site_name, "updated_at": updated_at},
         }
 
     def _is_forum_page(self, html_str: list[str]) -> bool:
