@@ -9,6 +9,7 @@ Registry and factory helpers for creating site-specific parsers.
 __all__ = ["register_parser", "get_parser"]
 
 from collections.abc import Callable, Sequence
+from importlib import import_module
 from typing import TypeVar
 
 from novel_downloader.core.interfaces import ParserProtocol
@@ -18,6 +19,7 @@ ParserBuilder = Callable[[ParserConfig], ParserProtocol]
 
 P = TypeVar("P", bound=ParserProtocol)
 _PARSER_MAP: dict[str, ParserBuilder] = {}
+_PARSERS_PKG = "novel_downloader.core.parsers"
 
 
 def register_parser(
@@ -27,7 +29,6 @@ def register_parser(
     Decorator to register a parser class under given keys.
 
     :param site_keys: Sequence of site identifiers
-    :param backends: Sequence of backend types
     :return: A class decorator that populates _PARSER_MAP.
     """
 
@@ -40,6 +41,33 @@ def register_parser(
     return decorator
 
 
+def _normalize_key(site_key: str) -> str:
+    """
+    Normalize a site key to the expected module basename:
+      * lowercase
+      * if first char is a digit, prefix with 'n'
+    """
+    key = site_key.strip().lower()
+    if not key:
+        raise ValueError("Site key cannot be empty")
+    if key[0].isdigit():
+        return f"n{key}"
+    return key
+
+
+def _load_parser(site_key: str) -> None:
+    """
+    Attempt to import the site-specific parser module.
+    """
+    modname = f"{_PARSERS_PKG}.{site_key}"
+    try:
+        import_module(modname)
+    except ModuleNotFoundError as e:
+        if e.name == modname:
+            return
+        raise
+
+
 def get_parser(site: str, config: ParserConfig) -> ParserProtocol:
     """
     Returns a site-specific parser instance.
@@ -48,10 +76,14 @@ def get_parser(site: str, config: ParserConfig) -> ParserProtocol:
     :param config: Configuration for the parser
     :return: An instance of a parser class
     """
-    site_key = site.lower()
-    try:
-        parser_cls = _PARSER_MAP[site_key]
-    except KeyError as err:
-        raise ValueError(f"Unsupported site: {site!r}") from err
+    site_key = _normalize_key(site)
+
+    parser_cls = _PARSER_MAP.get(site_key)
+    if parser_cls is None:
+        _load_parser(site_key)
+        parser_cls = _PARSER_MAP.get(site_key)
+
+    if parser_cls is None:
+        raise ValueError(f"Unsupported site: {site!r}")
 
     return parser_cls(config)
