@@ -11,7 +11,6 @@ __all__ = [
     "TextCleaner",
     "parse_cookies",
     "get_cookie_value",
-    "rc4_crypt",
     "sanitize_filename",
     "write_file",
     "download",
@@ -19,7 +18,6 @@ __all__ = [
     "content_prefix",
     "truncate_half_lines",
     "diff_inline_display",
-    "time_diff",
     "async_jitter_sleep",
     "jitter_sleep",
 ]
@@ -29,7 +27,6 @@ from .cookies import (
     get_cookie_value,
     parse_cookies,
 )
-from .crypto_utils import rc4_crypt
 from .file_utils import (
     sanitize_filename,
     write_file,
@@ -45,5 +42,4 @@ from .text_utils import (
 from .time_utils import (
     async_jitter_sleep,
     jitter_sleep,
-    time_diff,
 )
