@@ -16,14 +16,12 @@ from platformdirs import user_config_path
 # -----------------------------------------------------------------------------
 PACKAGE_NAME = "novel_downloader"  # Python package name
 APP_NAME = "NovelDownloader"  # Display name
-APP_DIR_NAME = PACKAGE_NAME  # Directory name for platformdirs
-LOGGER_NAME = PACKAGE_NAME  # Root logger name
 
 # -----------------------------------------------------------------------------
 # Base directories
 # -----------------------------------------------------------------------------
 # Base config directory (e.g. ~/AppData/Local/novel_downloader/)
-BASE_CONFIG_DIR = Path(user_config_path(APP_DIR_NAME, appauthor=False))
+BASE_CONFIG_DIR = user_config_path(PACKAGE_NAME, appauthor=False)
 WORK_DIR = Path.cwd()
 PACKAGE_ROOT: Path = Path(__file__).parent.parent
 LOCALES_DIR: Path = PACKAGE_ROOT / "locales"
@@ -84,14 +82,22 @@ VOLUME_BORDER_IMAGE_PATH = files("novel_downloader.resources.images").joinpath(
 )
 
 # JSON
-LINOVELIB_FONT_MAP_PATH = files("novel_downloader.resources.json").joinpath(
-    "linovelib_font_map.json"
+LINOVELIB_MAP_PATH = files("novel_downloader.resources.json").joinpath("linovelib.json")
+LINOVELIB_PCTHEMA_MAP_PATH = files("novel_downloader.resources.json").joinpath(
+    "linovelib_pctheme.json"
 )
-XIGUASHUWU_FONT_MAP_PATH = files("novel_downloader.resources.json").joinpath(
+XIGUASHUWU_MAP_PATH = files("novel_downloader.resources.json").joinpath(
     "xiguashuwu.json"
 )
+YODU_MAP_PATH = files("novel_downloader.resources.json").joinpath("yodu.json")
 
 # JavaScript
+EXPR_TO_JSON_SCRIPT_PATH = files("novel_downloader.resources.js_scripts").joinpath(
+    "expr_to_json.js"
+)
 QD_DECRYPT_SCRIPT_PATH = files("novel_downloader.resources.js_scripts").joinpath(
     "qidian_decrypt_node.js"
 )
+QQ_DECRYPT_SCRIPT_PATH = files("novel_downloader.resources.js_scripts").joinpath(
+    "qq_decrypt_node.js"
+)
