@@ -8,10 +8,11 @@ Utility for normalizing cookie input from user configuration.
 
 __all__ = ["parse_cookies", "get_cookie_value"]
 
+import functools
 import json
 from collections.abc import Mapping
-from http.cookies import SimpleCookie
 from pathlib import Path
+from typing import Any
 
 
 def parse_cookies(cookies: str | Mapping[str, str]) -> dict[str, str]:
@@ -27,10 +28,16 @@ def parse_cookies(cookies: str | Mapping[str, str]) -> dict[str, str]:
     :raises TypeError: If the input is neither string nor dict-like
     """
     if isinstance(cookies, str):
-        filtered = "; ".join(pair for pair in cookies.split(";") if "=" in pair)
-        parsed = SimpleCookie()
-        parsed.load(filtered)
-        return {k: v.value for k, v in parsed.items()}
+        result: dict[str, str] = {}
+        for part in cookies.split(";"):
+            if "=" not in part:
+                continue
+            key, value = part.split("=", 1)
+            key, value = key.strip(), value.strip()
+            if not key:
+                continue
+            result[key] = value
+        return result
     elif isinstance(cookies, Mapping):
         return {str(k).strip(): str(v).strip() for k, v in cookies.items()}
     raise TypeError("Unsupported cookie format: must be str or dict-like")
@@ -38,17 +45,25 @@ def parse_cookies(cookies: str | Mapping[str, str]) -> dict[str, str]:
 
 def get_cookie_value(state_files: list[Path], key: str) -> str:
     for state_file in state_files:
-        try:
-            with state_file.open("r", encoding="utf-8") as f:
-                data = json.load(f)
-        except Exception:
-            continue
-
+        mtime = state_file.stat().st_mtime
+        data = load_state_file(state_file, mtime)
         cookies = data.get("cookies", [])
-        for cookie in cookies:
-            if cookie.get("name") != key:
-                continue
-            value = cookie.get("value")
-            if isinstance(value, str):
-                return value
+        value = next(
+            (
+                c.get("value")
+                for c in cookies
+                if c.get("name") == key and isinstance(c.get("value"), str)
+            ),
+            None,
+        )
+        if isinstance(value, str):
+            return value
     return ""
+
+
+@functools.cache
+def load_state_file(state_file: Path, mtime: float = 0.0) -> dict[str, Any]:
+    try:
+        return json.loads(state_file.read_text(encoding="utf-8")) or {}
+    except (OSError, json.JSONDecodeError):
+        return {}
