@@ -5,9 +5,3 @@ novel_downloader.utils.crypto_utils
 
 Generic cryptographic utilities
 """
-
-__all__ = [
-    "rc4_crypt",
-]
-
-from .rc4 import rc4_crypt
