@@ -3,12 +3,7 @@
 novel_downloader.utils.epub.constants
 -------------------------------------
 
-EPUB-specific constants used by the builder, including:
-- Directory names for OEBPS structure
-- XML namespace URIs
-- Package attributes and document-type declarations
-- Media type mappings for images
-- Template strings for container.xml and cover image HTML
+EPUB-specific constants used by the builder.
 """
 
 ROOT_PATH = "OEBPS"
@@ -56,7 +51,7 @@ CSS_TMPLATE = (
 
 CHAP_TMPLATE = f"""\
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
+<!DOCTYPE html>
 <html xmlns="{XHTML_NS}" xmlns:epub="{EPUB_NS}" lang="{{lang}}" xml:lang="{{lang}}">
   <head>
     <title>{{title}}</title>
