@@ -4,14 +4,15 @@ novel_downloader.utils.epub.documents
 -------------------------------------
 
 Defines the classes that render EPUB navigation and packaging documents:
-- NavDocument: builds the XHTML nav.xhtml (EPUB 3)
-- NCXDocument: builds the NCX XML navigation map (EPUB 2)
-- OpfDocument: builds the content.opf package document
+  * NavDocument: builds the XHTML nav.xhtml (EPUB 3)
+  * NCXDocument: builds the NCX XML navigation map (EPUB 2)
+  * OpfDocument: builds the content.opf package document
 """
 
 from collections.abc import Sequence
 from dataclasses import dataclass, field
 from datetime import UTC, datetime
+from html import escape
 
 from .constants import (
     NAV_TEMPLATE,
@@ -31,7 +32,7 @@ from .models import (
 @dataclass
 class NavDocument(EpubResource):
     title: str = "未命名"
-    language: str = "zh-CN"
+    language: str = "zh-Hans"
     id: str = "nav"
     filename: str = "nav.xhtml"
     media_type: str = field(init=False, default="application/xhtml+xml")
@@ -76,7 +77,7 @@ class NavDocument(EpubResource):
         raw = NAV_TEMPLATE.format(
             lang=self.language,
             id=self.id,
-            title=self.title,
+            title=escape(self.title, quote=False),
             items=items_str,
         )
         return raw
@@ -85,15 +86,16 @@ class NavDocument(EpubResource):
     def _render_items_str(cls, items: Sequence[ChapterEntry | VolumeEntry]) -> str:
         lines: list[str] = []
         for item in items:
+            label = escape(item.label, quote=False)
             if isinstance(item, VolumeEntry) and item.chapters:
-                lines.append(f'<li><a href="{item.src}">{item.label}</a>')
+                lines.append(f'<li><a href="{item.src}">{label}</a>')
                 lines.append("  <ol>")
                 child = cls._render_items_str(item.chapters)
                 lines.extend(child.splitlines())
                 lines.append("  </ol>")
                 lines.append("</li>")
             else:
-                lines.append(f'<li><a href="{item.src}">{item.label}</a></li>')
+                lines.append(f'<li><a href="{item.src}">{label}</a></li>')
         return "\n".join(lines)
 
 
@@ -163,7 +165,8 @@ class NCXDocument(EpubResource):
         lines.append(f'<navPoint id="{pt.id}" playOrder="{order}">')
         order += 1
         # label and content
-        lines.append(f"<navLabel><text>{pt.label}</text></navLabel>")
+        label = escape(pt.label, quote=False)
+        lines.append(f"<navLabel><text>{label}</text></navLabel>")
         lines.append(f'<content src="{pt.src}"/>')
         # children
         for child in pt.children:
@@ -182,7 +185,7 @@ class OpfDocument(EpubResource):
     description: str = ""
     uid: str = ""
     subject: list[str] = field(default_factory=list)
-    language: str = "zh-CN"
+    language: str = "zh-Hans"
 
     # resource identity
     id: str = "opf"
@@ -234,28 +237,37 @@ class OpfDocument(EpubResource):
         Generate the content.opf XML, which defines metadata, manifest, and spine.
 
         This function outputs a complete OPF package document that includes:
-        - <metadata>: title, author, language, identifiers, etc.
-        - <manifest>: all resource entries
-        - <spine>: the reading order of the content
-        - <guide>: optional references like cover page
+          * <metadata>: title, author, language, identifiers, etc.
+          * <manifest>: all resource entries
+          * <spine>: the reading order of the content
+          * <guide>: optional references like cover page
 
         :return: A string containing the full OPF XML content.
         """
-        now_iso = datetime.now(UTC).replace(microsecond=0).isoformat()
+        now_iso = (
+            datetime.now(UTC).replace(microsecond=0).isoformat().replace("+00:00", "Z")
+        )
 
         # metadata block
         meta_lines: list[str] = []
         meta_lines.append(f'<meta property="dcterms:modified">{now_iso}</meta>')
         meta_lines.append(f'<dc:identifier id="id">{self.uid}</dc:identifier>')
-        meta_lines.append(f"<dc:title>{self.title}</dc:title>")
+        meta_lines.append(f"<dc:title>{escape(self.title, quote=True)}</dc:title>")
         meta_lines.append(f"<dc:language>{self.language}</dc:language>")
         if self.author:
-            meta_lines.append(f'<dc:creator id="creator">{self.author}</dc:creator>')
+            meta_lines.append(
+                f'<dc:creator id="creator">{escape(self.author, quote=True)}</dc:creator>'  # noqa: E501
+            )
+            meta_lines.append(
+                '<meta refines="#creator" property="role" scheme="marc:relators">aut</meta>'  # noqa: E501
+            )
         if self.description:
-            meta_lines.append(f"<dc:description>{self.description}</dc:description>")
+            meta_lines.append(
+                f"<dc:description>{escape(self.description, quote=True)}</dc:description>"  # noqa: E501
+            )
         if self.subject:
             joined = ",".join(self.subject)
-            meta_lines.append(f"<dc:subject>{joined}</dc:subject>")
+            meta_lines.append(f"<dc:subject>{escape(joined, quote=True)}</dc:subject>")
         if self.include_cover and self._cover_item:
             meta_lines.append(f'<meta name="cover" content="{self._cover_item.id}"/>')
         metadata = "\n".join(meta_lines)
