@@ -8,7 +8,6 @@ Utilities for handling HTTP requests and downloading remote resources.
 
 __all__ = ["download"]
 
-import logging
 from pathlib import Path
 from typing import Literal
 from urllib.parse import unquote, urlparse
@@ -19,10 +18,7 @@ from urllib3.util.retry import Retry
 
 from .constants import DEFAULT_HEADERS
 from .file_utils import sanitize_filename
-from .file_utils.io import _get_non_conflicting_path, write_file
-
-logger = logging.getLogger(__name__)
-_DEFAULT_CHUNK_SIZE = 8192  # 8KB per chunk for streaming downloads
+from .file_utils.io import _unique_path, write_file
 
 
 def _normalize_url(url: str) -> str:
@@ -37,8 +33,8 @@ def _normalize_url(url: str) -> str:
 
 
 def _build_filepath(
-    folder: Path,
     url: str,
+    folder: Path,
     filename: str | None,
     default_suffix: str,
     on_exist: Literal["overwrite", "skip", "rename"],
@@ -48,20 +44,18 @@ def _build_filepath(
 
     raw_name = filename or url_path.name or "unnamed"
     name = sanitize_filename(raw_name)
-    suffix = default_suffix or url_path.suffix
-    if suffix and not suffix.startswith("."):
-        suffix = "." + suffix
+
+    if "." not in name and (url_path.suffix or default_suffix):
+        name += url_path.suffix or default_suffix
 
     file_path = folder / name
-    if not file_path.suffix and suffix:
-        file_path = file_path.with_suffix(suffix)
-
     if on_exist == "rename":
-        file_path = _get_non_conflicting_path(file_path)
+        file_path = _unique_path(file_path)
+
     return file_path
 
 
-def _make_session(
+def _new_session(
     retries: int,
     backoff: float,
     headers: dict[str, str] | None,
@@ -72,7 +66,7 @@ def _make_session(
     retry = Retry(
         total=retries,
         backoff_factor=backoff,
-        status_forcelist=[429, 500, 502, 503, 504],
+        status_forcelist=[413, 429, 500, 502, 503, 504],
         allowed_methods={"GET", "HEAD", "OPTIONS"},
     )
     adapter = HTTPAdapter(max_retries=retry)
@@ -90,10 +84,8 @@ def download(
     retries: int = 3,
     backoff: float = 0.5,
     headers: dict[str, str] | None = None,
-    stream: bool = False,
     on_exist: Literal["overwrite", "skip", "rename"] = "overwrite",
     default_suffix: str = "",
-    chunk_size: int = _DEFAULT_CHUNK_SIZE,
 ) -> Path | None:
     """
     Download a URL to disk, with retries, optional rename/skip, and cleanup on failure.
@@ -105,10 +97,8 @@ def download(
     :param retries: GET retry count.
     :param backoff: exponential backoff base.
     :param headers: optional headers.
-    :param stream: Whether to stream the response.
     :param on_exist: if 'skip', return filepath; if 'rename', auto-rename.
     :param default_suffix: used if no suffix in URL or filename.
-    :param chunk_size: streaming chunk size.
     :return: path to the downloaded file.
     """
     url = _normalize_url(url)
@@ -117,8 +107,8 @@ def download(
     folder.mkdir(parents=True, exist_ok=True)
 
     save_path = _build_filepath(
-        folder,
         url,
+        folder,
         filename,
         default_suffix,
         on_exist,
@@ -126,34 +116,20 @@ def download(
 
     # Handle existing file
     if save_path.exists() and on_exist == "skip":
-        logger.debug("Skipping download; file exists: %s", save_path)
         return save_path
 
-    with _make_session(retries, backoff, headers) as session:
+    with _new_session(retries, backoff, headers) as session:
         try:
-            resp = session.get(url, timeout=timeout, stream=stream)
+            resp = session.get(url, timeout=timeout)
             resp.raise_for_status()
-        except Exception as e:
-            logger.warning("[download] request failed: %s", e)
-            return None
 
-        # Write to disk
-        if stream:
-            try:
-                with open(save_path, "wb") as f:
-                    for chunk in resp.iter_content(chunk_size=chunk_size):
-                        if chunk:
-                            f.write(chunk)
-                return save_path
-            except Exception as e:
-                logger.warning("[download] write failed: %s", e)
-                save_path.unlink(missing_ok=True)
-                return None
-        else:
+            # Write to disk
             return write_file(
                 content=resp.content,
                 filepath=save_path,
-                write_mode="wb",
                 on_exist=on_exist,
             )
+        except Exception:
+            return None
+
     return None
