@@ -6,11 +6,6 @@ novel_downloader.utils.time_utils
 Utility functions for time and date-related operations.
 """
 
-__all__ = [
-    "time_diff",
-    "async_jitter_sleep",
-    "jitter_sleep",
-]
+__all__ = ["async_jitter_sleep", "jitter_sleep"]
 
-from .datetime_utils import time_diff
 from .sleep_utils import async_jitter_sleep, jitter_sleep
