@@ -8,10 +8,12 @@ NiceGUI page registrations; importing this package exposes and registers all rou
 
 __all__ = [
     "page_download",  # /download
+    "page_history",  # /history
     "page_progress",  # /progress
     "page_search",  # /
 ]
 
 from .download import page_download
+from .history import page_history
 from .progress import page_progress
 from .search import page_search
